@@ -968,13 +968,7 @@ bivariate_ggplot_call <- function(x_class,
     )
     # Factor and character plots
   } else if (x_class == "factor" && y_class == "factor") {
-    plot_call <- reduce_plot_call(
-      plot_call,
-      substitute(
-        ggmosaic::geom_mosaic(aes(x = ggmosaic::product(xval), fill = yval), na.rm = TRUE),
-        env = list(xval = x, yval = y)
-      )
-    )
+    stop("Categorical variables 'x' and 'y' are currently not supported.")
   } else {
     stop("x y type combination not allowed")
   }
