@@ -31,8 +31,6 @@
 #' This module generates the following objects, which can be modified in place using decorators::
 #' - `histogram_plot` (`ggplot`)
 #' - `qq_plot` (`ggplot`)
-#' - `summary_table` (`datatables` created with [DT::datatable()])
-#' - `test_table` (`datatables` created with [DT::datatable()])
 #'
 #' A Decorator is applied to the specific output using a named list of `teal_transform_module` objects.
 #' The name of this list corresponds to the name of the output to which the decorator is applied.
@@ -43,9 +41,7 @@
 #'    ..., # arguments for module
 #'    decorators = list(
 #'      histogram_plot = teal_transform_module(...), # applied only to `histogram_plot` output
-#'      qq_plot = teal_transform_module(...), # applied only to `qq_plot` output
-#'      summary_table = teal_transform_module(...), # applied only to `summary_table` output
-#'      test_table = teal_transform_module(...) # applied only to `test_table` output
+#'      qq_plot = teal_transform_module(...) # applied only to `qq_plot` output
 #'    )
 #' )
 #' ```
@@ -194,8 +190,7 @@ tm_g_distribution <- function(label = "Distribution Module",
   checkmate::assert_multi_class(pre_output, c("shiny.tag", "shiny.tag.list", "html"), null.ok = TRUE)
   checkmate::assert_multi_class(post_output, c("shiny.tag", "shiny.tag.list", "html"), null.ok = TRUE)
 
-  available_decorators <- c("histogram_plot", "qq_plot", "test_table", "summary_table")
-  assert_decorators(decorators, names = available_decorators)
+  assert_decorators(decorators, names = c("histogram_plot", "qq_plot"))
 
   # End of assertions
 
@@ -259,7 +254,8 @@ ui_distribution <- function(id, ...) {
     ),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
       tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(args[c("dist_var", "strata_var")]),
@@ -288,10 +284,10 @@ ui_distribution <- function(id, ...) {
           is_single_dataset = is_single_dataset_value
         )
       },
-      teal.widgets::panel_group(
+      bslib::accordion(
         conditionalPanel(
           condition = paste0("input['", ns("tabs"), "'] == 'Histogram'"),
-          teal.widgets::panel_item(
+          bslib::accordion_panel(
             "Histogram",
             teal.widgets::optionalSliderInputValMinMax(ns("bins"), "Bins", args$bins, ticks = FALSE, step = 1),
             shinyWidgets::prettyRadioButtons(
@@ -306,13 +302,12 @@ ui_distribution <- function(id, ...) {
             ui_decorate_teal_data(
               ns("d_density"),
               decorators = select_decorators(args$decorators, "histogram_plot")
-            ),
-            collapsed = FALSE
+            )
           )
         ),
         conditionalPanel(
           condition = paste0("input['", ns("tabs"), "'] == 'QQplot'"),
-          teal.widgets::panel_item(
+          bslib::accordion_panel(
             "QQ Plot",
             checkboxInput(ns("qq_line"), label = "Add diagonal line(s)", TRUE),
             ui_decorate_teal_data(
@@ -322,28 +317,20 @@ ui_distribution <- function(id, ...) {
             collapsed = FALSE
           )
         ),
-        ui_decorate_teal_data(
-          ns("d_summary"),
-          decorators = select_decorators(args$decorators, "summary_table")
-        ),
-        ui_decorate_teal_data(
-          ns("d_test"),
-          decorators = select_decorators(args$decorators, "test_table")
-        ),
         conditionalPanel(
           condition = paste0("input['", ns("main_type"), "'] == 'Density'"),
-          teal.widgets::panel_item(
+          bslib::accordion_panel(
             "Theoretical Distribution",
             teal.widgets::optionalSelectInput(
               ns("t_dist"),
               tags$div(
-                class = "teal-tooltip",
                 tagList(
                   "Distribution:",
-                  icon("circle-info"),
-                  tags$span(
-                    class = "tooltiptext",
-                    "Default parameters are optimized with MASS::fitdistr function."
+                  bslib::tooltip(
+                    icon("circle-info"),
+                    tags$span(
+                      "Default parameters are optimized with MASS::fitdistr function."
+                    )
                   )
                 )
               ),
@@ -356,39 +343,39 @@ ui_distribution <- function(id, ...) {
             tags$span(actionButton(ns("params_reset"), "Default params")),
             collapsed = FALSE
           )
-        )
-      ),
-      teal.widgets::panel_item(
-        "Tests",
-        teal.widgets::optionalSelectInput(
-          ns("dist_tests"),
-          "Tests:",
-          choices = c(
-            "Shapiro-Wilk",
-            if (!is.null(args$strata_var)) "t-test (two-samples, not paired)",
-            if (!is.null(args$strata_var)) "one-way ANOVA",
-            if (!is.null(args$strata_var)) "Fligner-Killeen",
-            if (!is.null(args$strata_var)) "F-test",
-            "Kolmogorov-Smirnov (one-sample)",
-            "Anderson-Darling (one-sample)",
-            "Cramer-von Mises (one-sample)",
-            if (!is.null(args$strata_var)) "Kolmogorov-Smirnov (two-samples)"
-          ),
-          selected = NULL
-        )
-      ),
-      teal.widgets::panel_item(
-        "Statistics Table",
-        sliderInput(ns("roundn"), "Round to n digits", min = 0, max = 10, value = 2)
-      ),
-      teal.widgets::panel_item(
-        title = "Plot settings",
-        selectInput(
-          inputId = ns("ggtheme"),
-          label = "Theme (by ggplot):",
-          choices = ggplot_themes,
-          selected = args$ggtheme,
-          multiple = FALSE
+        ),
+        bslib::accordion_panel(
+          title = "Tests",
+          teal.widgets::optionalSelectInput(
+            ns("dist_tests"),
+            "Tests:",
+            choices = c(
+              "Shapiro-Wilk",
+              if (!is.null(args$strata_var)) "t-test (two-samples, not paired)",
+              if (!is.null(args$strata_var)) "one-way ANOVA",
+              if (!is.null(args$strata_var)) "Fligner-Killeen",
+              if (!is.null(args$strata_var)) "F-test",
+              "Kolmogorov-Smirnov (one-sample)",
+              "Anderson-Darling (one-sample)",
+              "Cramer-von Mises (one-sample)",
+              if (!is.null(args$strata_var)) "Kolmogorov-Smirnov (two-samples)"
+            ),
+            selected = NULL
+          )
+        ),
+        bslib::accordion_panel(
+          title = "Statistics Table",
+          sliderInput(ns("roundn"), "Round to n digits", min = 0, max = 10, value = 2)
+        ),
+        bslib::accordion_panel(
+          title = "Plot settings",
+          selectInput(
+            inputId = ns("ggtheme"),
+            label = "Theme (by ggplot):",
+            choices = ggplot_themes,
+            selected = args$ggtheme,
+            multiple = FALSE
+          )
         )
       )
     ),
@@ -596,7 +583,18 @@ srv_distribution <- function(id,
           }
 
         params_vals <- unname(params)
-        params_names <- names(params)
+        map_distr_nams <- list(
+          normal = c("mean", "sd"),
+          lognormal = c("meanlog", "sdlog"),
+          gamma = c("shape", "rate"),
+          unif = c("min", "max")
+        )
+
+        if (!is.null(input$t_dist) && input$t_dist %in% names(map_distr_nams)) {
+          params_names <- map_distr_nams[[input$t_dist]]
+        } else {
+          params_names <- names(params)
+        }
 
         updateNumericInput(
           inputId = "dist_param1",
@@ -1273,24 +1271,31 @@ srv_distribution <- function(id,
     # Summary table listing has to be created separately to allow for qenv join
     output_summary_q <- reactive({
       if (iv_r()$is_valid()) {
-        within(common_q(), summary_table <- DT::datatable(summary_table_data))
+        within(common_q(), {
+          summary_table <- rtables::df_to_tt(summary_table_data)
+          summary_table
+        })
       } else {
-        within(common_q(), summary_table <- DT::datatable(summary_table_data[0L, ]))
+        within(
+          common_q(),
+          summary_table <- rtables::rtable(header = rtables::rheader(colnames(summary_table_data)))
+        )
       }
     })
 
     output_test_q <- reactive({
       # wrapped in if since could lead into validate error - we do want to continue
       test_q_out <- try(test_q(), silent = TRUE)
-      if (!inherits(test_q_out, c("try-error", "error"))) {
-        c(
+      if (inherits(test_q_out, c("try-error", "error"))) {
+        within(
           common_q(),
-          within(test_q_out, {
-            test_table <- DT::datatable(test_table_data)
-          })
+          test_table <- rtables::rtable(header = rtables::rheader("No data available in table"), rtables::rrow())
         )
       } else {
-        within(common_q(), test_table <- DT::datatable(data.frame(missing = character(0L))))
+        within(c(common_q(), test_q_out), {
+          test_table <- rtables::df_to_tt(test_table_data)
+          test_table
+        })
       }
     })
 
@@ -1308,54 +1313,47 @@ srv_distribution <- function(id,
       expr = print(qq_plot)
     )
 
-    decorated_output_summary_q <- srv_decorate_teal_data(
-      "d_summary",
-      data = output_summary_q,
-      decorators = select_decorators(decorators, "summary_table"),
-      expr = summary_table
-    )
-
-    decorated_output_test_q <- srv_decorate_teal_data(
-      "d_test",
-      data = output_test_q,
-      decorators = select_decorators(decorators, "test_table"),
-      expr = test_table
-    )
-
     decorated_output_q <- reactive({
       tab <- req(input$tabs) # tab is NULL upon app launch, hence will crash without this statement
       test_q_out <- try(test_q(), silent = TRUE)
-      decorated_test_q_out <- if (inherits(test_q_out, c("try-error", "error"))) {
-        teal.code::qenv()
-      } else {
-        decorated_output_test_q()
-      }
+      test_q_out <- output_test_q()
 
       out_q <- switch(tab,
         Histogram = decorated_output_dist_q(),
         QQplot = decorated_output_qq_q()
       )
-      c(out_q, decorated_output_summary_q(), decorated_test_q_out)
+      c(out_q, output_summary_q(), test_q_out)
     })
 
     dist_r <- reactive(req(decorated_output_dist_q())[["histogram_plot"]])
 
     qq_r <- reactive(req(decorated_output_qq_q())[["qq_plot"]])
 
-    output$summary_table <- DT::renderDataTable(
-      expr = decorated_output_summary_q()[["summary_table"]],
-      options = list(
-        autoWidth = TRUE,
-        columnDefs = list(list(width = "200px", targets = "_all"))
-      ),
-      rownames = FALSE
-    )
+    summary_r <- reactive({
+      q <- req(output_summary_q())
+
+      list(
+        html = DT::datatable(
+          q[["summary_table_data"]],
+          options = list(
+            autoWidth = TRUE,
+            columnDefs = list(list(width = "200px", targets = "_all"))
+          ),
+          rownames = FALSE
+        ),
+        report = q[["summary_table"]]
+      )
+    })
+
+    output$summary_table <- DT::renderDataTable(summary_r()[["html"]])
 
     tests_r <- reactive({
-      req(iv_r()$is_valid())
-      teal::validate_inputs(iv_r_dist())
-      req(test_q()) # Ensure original errors are displayed
-      decorated_output_test_q()[["test_table"]]
+      q <- req(output_test_q())
+
+      list(
+        html = DT::datatable(q[["test_table_data"]]),
+        report = q[["test_table"]]
+      )
     })
 
     pws1 <- teal.widgets::plot_with_settings_srv(
@@ -1374,7 +1372,7 @@ srv_distribution <- function(id,
       brushing = FALSE
     )
 
-    output$t_stats <- DT::renderDataTable(expr = tests_r())
+    output$t_stats <- DT::renderDataTable(tests_r()[["html"]])
 
     # Render R code.
     source_code_r <- reactive(teal.code::get_code(req(decorated_output_q())))
@@ -1401,11 +1399,11 @@ srv_distribution <- function(id,
           card$append_plot(qq_r(), dim = pws2$dim())
         }
         card$append_text("Statistics table", "header3")
-        card$append_table(decorated_output_summary_q()[["summary_table"]])
+        card$append_table(summary_r()[["report"]])
         tests_error <- tryCatch(expr = tests_r(), error = function(e) "error")
-        if (inherits(tests_error, "data.frame")) {
+        if (!identical(tests_error, "error")) {
           card$append_text("Tests table", "header3")
-          card$append_table(tests_r())
+          card$append_table(tests_r()[["report"]])
         }
 
         if (!comment == "") {
@@ -1415,7 +1413,7 @@ srv_distribution <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
